#' @useDynLib mmapcharr, .registration = TRUE
#' @importFrom Rcpp sourceCpp
#' @importFrom methods new
#' 
#' @keywords internal
"_PACKAGE"
